<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" xmlns:op="utc.fr:ics/opale3"
	xmlns="http://www2.educnet.education.fr/sections/superieur/unt/inter/chaine-editoria"
	exclude-result-prefixes="sc sp op">
	
	<xsl:import href="bsco:export.xsl" />
	<xsl:import href="bsco:interunt.xsl" />

	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />

	<xsl:param name="vDialog" />
	<xsl:param name="vAgent" />

	<xsl:template match="op:practUc">
		<docInterUnt>
			<xsl:call-template name="tIdElt" />
			<type>Exercice</type>
			<titre>
				<xsl:value-of select="op:uM/sp:title" disable-output-escaping="yes" />
			</titre>
			<xsl:call-template name="tLevelElt" />
			<xsl:call-template name="tIncrementLevel" />
			
			<xsl:value-of select="getContent(gotoMeta())" disable-output-escaping="yes" />
			
			<contenu>
				<exercice>
					<xsl:call-template name="tIdElt" />
					<type>
						<xsl:apply-templates select="." mode="label" />
					</type>
					<typeEvaluation>auto-évaluation</typeEvaluation>
					<xsl:if test="count(sp:desc)">
						<xsl:if test="count(sp:desc) &gt; 1">
							<xsl:call-template name="tLogWarning">
								<xsl:with-param name="pMessage">Les mises en contexte ont été regroupées dans un unique énoncé.</xsl:with-param>
							</xsl:call-template>
						</xsl:if>

						<enonce>
							<xsl:apply-templates select="sp:desc" />
						</enonce>
					</xsl:if>
					
					<xsl:apply-templates select='sp:quest' />
				</exercice>
			</contenu>

			<xsl:call-template name="tRefs" />
		</docInterUnt>
	</xsl:template>
	
	<xsl:template match="op:uM" />

	<xsl:template match="sp:desc">
		<xsl:apply-templates select="op:sTitle" />
		<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
	</xsl:template>

	<xsl:template match="sp:desc/op:sTitle">
		<paragraphe>
			<emphase>
				<xsl:value-of select="sc:fullTitle" />
			</emphase>
		</paragraphe>
	</xsl:template>

	<xsl:template match="sp:quest">
		<question>
			<xsl:apply-templates />
		</question>
	</xsl:template>

	<xsl:template match="op:practUcQ">
		<xsl:apply-templates select="*[not(self::sp:sol)]" />
		<xsl:if test="count(sp:sol)">
			<solution>
				<xsl:choose>
					<xsl:when test="count(sp:sol) &gt; 1">
						<xsl:call-template name="tLogWarning">
							<xsl:with-param name="pMessage">Les solutions ont été regroupées en une seule et numérotés.</xsl:with-param>
						</xsl:call-template>
						<xsl:apply-templates select="sp:sol" mode="title" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="sp:sol" />
					</xsl:otherwise>
				</xsl:choose>
			</solution>
		</xsl:if>
	</xsl:template>

	<xsl:template match="op:practUcQ/sp:desc">
		<enonce>
			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</enonce>
	</xsl:template>

	<xsl:template match="op:practUcQ/sp:hint">
		<aide>
			<xsl:value-of select="getContent(gotoSubModel())" disable-output-escaping="yes" />
		</aide>
	</xsl:template>

	<xsl:template match="op:practUcQ/sp:sol" mode="title">
		<paragraphe>
			<emphase>
				<xsl:text>Solution </xsl:text>
				<xsl:value-of select="count(preceding-sibling::sp:sol) + 1" />
			</emphase>
		</paragraphe>
		<xsl:apply-templates select="." />
	</xsl:template>
	
	<xsl:template match="op:practUcQ/sp:sol">
		<xsl:call-template name="tLogWarning">
			<xsl:with-param name="pMessage">Les balises pédagogiques ne sont pas permises dans les
				solutions d&apos;inter-UNT. Elles ont été mises à plat.</xsl:with-param>
		</xsl:call-template>

		<xsl:value-of select="getContent(gotoSubModel(), 'flat')" disable-output-escaping="yes"
		 />
	</xsl:template>

</xsl:stylesheet>
