<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
				xmlns:sc="http://www.utc.fr/ics/scenari/v3/core"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" 
				xmlns:op="utc.fr:ics/opale3"
				exclude-result-prefixes="sc sp op">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" />
	
	<xsl:include href="bsco:export.xsl" />
	<xsl:include href="bsco:uved.xsl" />
	<xsl:include href="bsco:uved.txt.inline.xsl" />
	
	<xsl:template match="op:sPara | op:sTxt | op:txt | op:qTxt">
		<xsl:apply-templates/>
	</xsl:template>
	
	<!-- # Paragraphes -->
	<xsl:template match="sc:para">
		<PARAGRAPHE>
			<xsl:apply-templates/>
		</PARAGRAPHE>
		<!-- Images inline non gérées dans UVED => affichées aprés -->
		<xsl:if test="not(ancestor::sc:itemizedList) and not(ancestor::sc:orderedList)">
			<xsl:apply-templates select="sc:inlineImg" mode="afterPara"/>
		</xsl:if>
	</xsl:template>
	
	<!-- # Listes -->
	<xsl:template match="sc:itemizedList">
		<LISTE type="puces">
			<xsl:apply-templates/>
		</LISTE>
		<!-- Images inline non gérées dans UVED => affichées aprés la liste -->
		<xsl:if test="not(ancestor::sc:itemizedList) and not(ancestor::sc:orderedList)">
			<xsl:apply-templates select=".//sc:inlineImg" mode="afterPara"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="sc:orderedList">
		<LISTE type="numéros">
			<xsl:apply-templates/>
		</LISTE>
		<!-- Images inline non gérées dans UVED => affichées aprés la liste -->
		<xsl:if test="not(ancestor::sc:itemizedList) and not(ancestor::sc:orderedList)">
			<xsl:apply-templates select=".//sc:inlineImg" mode="afterPara"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="sc:listItem">
		<ITEM>
			<xsl:apply-templates/>
		</ITEM>
	</xsl:template>
	
	<!-- # Tableaux -->
	<xsl:template match="sc:table">
	   <ZONETABLE>
	       <xsl:call-template name="tLogWarning">
               <xsl:with-param name="pMessage">La largeur des colonnes du tableau n&apos;ont pas d&apos;équivalent dans UVED et n&apos;ont donc pas été récupérées.</xsl:with-param>
           </xsl:call-template>
	       <TABLE>
	           <xsl:apply-templates select="sc:row"/>
	       </TABLE>
	       <xsl:apply-templates select="sc:caption"/>
	   </ZONETABLE>
	</xsl:template>
	
	<xsl:template match="sc:caption">
	   <LEGENDE><xsl:apply-templates/></LEGENDE>
	</xsl:template>
	
	<xsl:template match="sc:row">
	   <TR>
	       <xsl:apply-templates/>
	   </TR>
	</xsl:template>
	
	<xsl:template match="sc:cell">
	   <xsl:variable name="vTagName" select="si(ancestor::sc:row[@role='head'], 'TH', 'TD')"/>
	   <xsl:element name="{$vTagName}">
	       <xsl:attribute name="align"><xsl:value-of select="si(@role='num', 'right', si(@role='word', 'center', 'left'))"/></xsl:attribute>
	       <xsl:if test="count(sc:para)&gt;1">
	           <xsl:call-template name="tLogWarning">
	               <xsl:with-param name="pMessage">UVED n&apos;autorise qu&apos;un seul paragraphe dans les cellules des tableaux; le contenu a donc été modifié.</xsl:with-param>
	           </xsl:call-template>
	       </xsl:if>
	       <xsl:apply-templates select="sc:para/* | sc:para/text()"/>
	   </xsl:element>
	</xsl:template>
	
		
</xsl:stylesheet>



